@@ -14,9 +14,10 @@ from typing import Tuple, Optional
 from appium.webdriver import Remote
 import time
 from selenium.common.exceptions import NoSuchElementException
-from supbot import model, g, helper
+from supbot import g, helper
 
 
+# noinspection PyBroadException
 class AppDriver:
     """
     Abstracts appium calls
@@ -29,7 +30,6 @@ class AppDriver:
     def create() -> Optional['AppDriver']:
         """
         Initializes appium driver
-        :type device_name: name of the device to be used, if it is none, it uses adb command to fetch it
         """
         try:
             run_server = not ("no_server" in g.kwargs and g.kwargs["no_server"])
@@ -53,7 +53,8 @@ class AppDriver:
                 def appium_logging():
                     g.logger.info("launching appium server on {}".format(port))
                     try:
-                        appium_process = subprocess.Popen(shlex.split("appium --port {}".format(port)), stdout=subprocess.PIPE, shell=True)
+                        appium_process = subprocess.Popen(shlex.split("appium --port {}".format(port)),
+                                                          stdout=subprocess.PIPE, shell=True)
                         appium_logs = logging.getLogger('appium')
                         while g.system.status > -1:
                             line = appium_process.stdout.readline().decode('utf-8')
@@ -100,14 +101,21 @@ class AppDriver:
         except Exception:
             return False
 
-    def search_chat(self, chat_name: str) -> bool:
+    def type_in_search(self, chat_name: str) -> bool:
         try:
-            self.driver.find_element_by_id("com.whatsapp:id/menuitem_search").click()
             self.driver.find_element_by_id("com.whatsapp:id/search_src_text").send_keys(chat_name)
             return True
         except NoSuchElementException:
             return False
 
+    def click_search(self) -> bool:
+        try:
+            self.driver.find_element_by_id("com.whatsapp:id/menuitem_search").click()
+            self.press_back()
+            return True
+        except:
+            return False
+
     def chat_via_intent(self, phone_number):
         try:
             self.driver.start_activity("com.whatsapp", "com.whatsapp.Conversation",
@@ -128,6 +136,7 @@ class AppDriver:
 
             element = self.driver.find_element_by_id('com.whatsapp:id/send')
             element.click()
+
             return True
         except NoSuchElementException:
             return False
@@ -151,7 +160,7 @@ class AppDriver:
         time.sleep(0.5)
         self.driver.press_keycode(4)
 
-    def get_new_chat(self) -> Optional['model.Chat']:
+    def get_new_chat(self) -> Optional[str]:
         """
         Checks for chat item with new message bubble,
         used by new_chat checker (checker system not made yet)
@@ -162,7 +171,7 @@ class AppDriver:
                                                         '"com.whatsapp:id/conversations_row_message_count"]/../..'
                                                         '//android.widget.TextView[@resource-id="com.whatsapp:id'
                                                         '/conversations_row_contact_name"]')
-            return model.Chat(element.text)
+            return element.text
         except NoSuchElementException:
             return None
 
@@ -196,3 +205,22 @@ class AppDriver:
             return True
         except:
             return False
+
+    def check_search_button(self):
+        try:
+            return self.driver.find_element_by_id("com.whatsapp:id/menuitem_search") is not None
+        except:
+            return False
+
+    def check_search_input(self):
+        try:
+            return self.driver.find_element_by_id("com.whatsapp:id/search_src_text") is not None
+        except:
+            return False
+
+    def check_chat(self, chat_name):
+        try:
+            element = self.driver.find_element_by_id("com.whatsapp:id/conversation_contact_name")
+            return helper.contact_number_equal(element.text, chat_name)
+        except:
+            return False
